@@ -21,29 +21,76 @@ MITO_PRIMITIVE_TYPE_MAPPING = {
     'string': [str],
 }
 
-
 BOOLEAN_SERIES = 'boolean_series'
 DATETIME_SERIES = 'datetime_series'
 TIMEDELTA_SERIES = 'timedelta_series'
 NUMBER_SERIES = 'number_series'
 STRING_SERIES = 'string_series'
 
-# NOTE: these are the dtype strings of series used by pandas!
-MITO_SERIES_TYPE_MAPPING = {
-    BOOLEAN_SERIES: ['bool'],
-    DATETIME_SERIES: ['datetime64[ns]'],
-    TIMEDELTA_SERIES: ['timedelta64[ns]'],
-    NUMBER_SERIES: ['int64', 'float64'],
-    STRING_SERIES: ['str', 'object'],
-}
+# A series of helper functions that help you figure
+# out which dtype we're dealing with. NOTE: since some
+# of these types can be different varieties (e.g. int can be int64, uint64)
+# we try to check for them with simple expressions
+
+def is_bool_dtype(dtype):
+    return 'bool' == dtype
+
+def is_int_dtype(dtype):
+    return 'int' in dtype
+
+def is_float_dtype(dtype):
+    return 'float' in dtype
+
+def is_string_dtype(dtype):
+    return dtype == 'object' or dtype == 'str' or dtype == 'string'
+
+def is_datetime_dtype(dtype):
+    # NOTE: this should handle all different datetime columns, no matter
+    # the timezone, as it checks for string inclusion
+    return 'datetime' in dtype
+
+def is_timedelta_dtype(dtype):
+    return 'timedelta' in dtype
+
+def get_datetime_columns(df: pd.DataFrame):
+    """
+    Returns all the datetime column_headers in the
+    passed dataframe
+    """
+    datetime_columns = []
+    for column_header in df.columns:
+        if is_datetime_dtype(str(df[column_header].dtype)):
+            datetime_columns.append(column_header)
+    return datetime_columns
+
+def get_timedelta_columns(df: pd.DataFrame):
+    """
+    Returns all the timedelta column_headers in the
+    passed dataframe
+    """
+    timedelta_columns = []
+    for column_header in df.columns:
+        if is_timedelta_dtype(str(df[column_header].dtype)):
+            timedelta_columns.append(column_header)
+    return timedelta_columns
 
 def get_mito_type(obj):
 
     if isinstance(obj, pd.Series):
-        dtype = obj.dtype
-        for key, value in MITO_SERIES_TYPE_MAPPING.items():
-            if dtype in value:
-                return key
+        dtype = str(obj.dtype)
+        if is_bool_dtype(dtype):
+            return BOOLEAN_SERIES
+        elif is_int_dtype(dtype) or is_float_dtype(dtype):
+            return NUMBER_SERIES
+        elif is_string_dtype(dtype):
+            return STRING_SERIES
+        elif is_datetime_dtype(dtype):
+            return DATETIME_SERIES
+        elif is_timedelta_dtype(dtype):
+            return TIMEDELTA_SERIES
+        else:
+            # We default to string, when not sure what else
+            return STRING_SERIES
 
     elif isinstance(obj, pd.Timestamp):
         return 'timestamp'
@@ -115,4 +162,4 @@ def put_nan_indexes_back(series, nan_indexes):
         real_index +=1
 
     final_series = pd.Series(final_series)
-    return final_series
\ No newline at end of file
+    return final_series
