@@ -18,10 +18,6 @@ MITO_FOLDER = os.path.expanduser("~/.mito")
 # The path of the user.json file
 USER_JSON_PATH = os.path.join(MITO_FOLDER, 'user.json')
 
-# The path of the user_install.json, which notably exists if the
-# user has used the installer
-USER_INSTALL_PATH = os.path.join(MITO_FOLDER, 'user_install.json')
-
 
 def get_user_field(field, path=USER_JSON_PATH):
     """
